package jrummikub.view.impl;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Insets;
import java.util.Collection;
import java.util.Collections;

import javax.swing.border.EmptyBorder;

import jrummikub.model.Position;
import jrummikub.model.Stone;
import jrummikub.view.IStoneCollection;

@SuppressWarnings("serial")
class StoneCollection extends StonePanel implements IStoneCollection {
  private final static int INSET = 7;
  private final static float STONE_SCALE = 1.1f;

  private Collection<Stone> selectedStones = Collections.emptyList();

  StoneCollection() {
    super(STONE_SCALE);

    setOpaque(false);
    setVisible(false);
    setBorder(new EmptyBorder(INSET, INSET, INSET, INSET));
  }

  void setSelectedStones(Collection<Stone> stones) {
    selectedStones = stones;

    if (stones.isEmpty()) {
      setVisible(false);
    } else {
      setSize(getStonePainter().getStoneWidth() * stones.size() + 2 * INSET,
          getStonePainter().getStoneHeight() + 2 * INSET);
      setVisible(true);

      repaint();
    }
  }

  @Override
  public void paintComponent(Graphics g1) {
    Insets insets = getInsets();
    int x = insets.left, y = insets.top, width = getWidth() - insets.left
        - insets.right, height = getHeight() - insets.top - insets.bottom;
    Graphics2D g = (Graphics2D) g1.create(x, y, width, height);

    if (!selectedStones.isEmpty()) {
      g1.setColor(new Color(0, 0, 0, 0.25f));
      g1.fillRoundRect(0, 0, getWidth(), getHeight(), INSET, INSET);

      float xpos = 0;

      for (Stone stone : selectedStones) {
        getStonePainter().paintStone(g, stone, new Position(xpos, 0),
            false);
        xpos++;
      }
    }
  }
}
